@@ -23,7 +23,7 @@ import yaml
 
 from howso.utilities.features import FeatureType
 from howso.utilities.internals import serialize_models
-from howso.utilities.utilities import is_valid_datetime_format
+from howso.utilities.utilities import is_valid_datetime_format, time_to_seconds
 
 logger = logging.getLogger(__name__)
 
@@ -255,15 +255,16 @@ class FeatureAttributesBase(dict):
             elif out_of_band_values:
                 errors.append(f"'{feature}' contains out-of-band values: {out_of_band_values}")
         elif attributes.get('date_time_format'):
-            # Since this is a datetime feature, convert dates to epoch time for bounds comparison
-            try:
-                if min_bound:
-                    min_bound_epoch = date_to_epoch(min_bound, time_format=attributes['date_time_format'])
-                if max_bound:
-                    max_bound_epoch = date_to_epoch(max_bound, time_format=attributes['date_time_format'])
-                for value in unique_values:
-                    epoch = date_to_epoch(value, time_format=attributes['date_time_format'])
-                    if (max_bound and epoch > max_bound_epoch) or (min_bound and epoch < min_bound_epoch):
+            # Time-only attributes have bounds represented in seconds
+            if attributes.get('original_type', {}).get('data_type') == 'time':
+                unique_time_values = pd.to_datetime(
+                    series,
+                    format=attributes['date_time_format'],
+                    errors='coerce'
+                ).dropna().unique()
+                for value in unique_time_values:
+                    value_in_seconds = time_to_seconds(value.time())
+                    if (max_bound and value_in_seconds > max_bound) or (min_bound and value_in_seconds < min_bound):
                         if len(errors) < 5:
                             errors.append(
                                 f'"{feature}" has a value outside of bounds '
@@ -271,8 +272,25 @@ class FeatureAttributesBase(dict):
                             )
                         else:
                             additional_errors += 1
-            except ValueError as err:
-                errors.append(f'Could not validate datetime bounds due to the following error: {err}')
+            # If this is a datetime feature, convert dates to epoch time for bounds comparison
+            else:
+                try:
+                    if min_bound:
+                        min_bound_epoch = date_to_epoch(min_bound, time_format=attributes['date_time_format'])
+                    if max_bound:
+                        max_bound_epoch = date_to_epoch(max_bound, time_format=attributes['date_time_format'])
+                    for value in unique_values:
+                        epoch = date_to_epoch(value, time_format=attributes['date_time_format'])
+                        if (max_bound and epoch > max_bound_epoch) or (min_bound and epoch < min_bound_epoch):
+                            if len(errors) < 5:
+                                errors.append(
+                                    f'"{feature}" has a value outside of bounds '
+                                    f'(min: {min_bound}, max: {max_bound}): {value}'
+                                )
+                            else:
+                                additional_errors += 1
+                except ValueError as err:
+                    errors.append(f'Could not validate datetime bounds due to the following error: {err}')
         elif min_bound or max_bound:
             # Check int/float bounds
             for value in unique_values:
@@ -296,6 +314,7 @@ class FeatureAttributesBase(dict):
         errors = []
         series = coerced_df[feature]
         is_valid = False
+        coerce_err = ""
 
         if isinstance(expected_dtype, pd.CategoricalDtype):
             # If the feature is a Categorical dtype, try to coerce
@@ -337,14 +356,16 @@ class FeatureAttributesBase(dict):
                     # If this happens, there is a null value, thus a float dtype is OK
                     if pd.api.types.is_float_dtype(series):
                         is_valid = True
-                except Exception: # noqa: Intentionally broad
+                except Exception as err: # noqa: Intentionally broad
+                    coerce_err = str(err)
                     pass
 
         # Raise warnings if the types do not match
         if not is_valid:
             if coerce:
                 errors.append(f"Expected dtype '{expected_dtype}' for feature '{feature}' "
-                              "but could not coerce.")
+                              f"but could not coerce:\nActual dtype: {data[feature].dtype}"
+                              f"\nError raised from Pandas.astype():\n\n{coerce_err}")
             else:
                 errors.append(f"Feature '{feature}' should be '{expected_dtype}' dtype, but found "
                               f"'{data[feature].dtype}'")
@@ -358,7 +379,7 @@ class FeatureAttributesBase(dict):
 
     def _validate_df(self, data: pd.DataFrame, coerce: bool = False,  # noqa: C901
                      raise_errors: bool = False, table_name: t.Optional[str] = None, validate_bounds=True,
-                     allow_missing_features: bool = False, localize_datetimes=True):
+                     allow_missing_features: bool = False, localize_datetimes=True, nullable_int_dtype='Int64'):
         errors = []
         coerced_df = data.copy(deep=True)
         features = self[table_name] if table_name else self
@@ -382,9 +403,13 @@ class FeatureAttributesBase(dict):
             if attributes['type'] == 'nominal':
                 if attributes.get('data_type') == 'number':
                     # Check type (float)
-                    if attributes.get('decimal_places', 0) > 0 or self._allows_null(attributes):
+                    if attributes.get('decimal_places', 0) > 0:
                         errors.extend(self._validate_dtype(data, feature, 'float64',
                                                            coerced_df, coerce=coerce))
+                    # Check type (nullable Int)
+                    elif self._allows_null(attributes):
+                        errors.extend(self._validate_dtype(data, feature, nullable_int_dtype,
+                                                           coerced_df, coerce=coerce))
                     # Check type (int)
                     else:
                         errors.extend(self._validate_dtype(data, feature, 'int64',
@@ -413,27 +438,35 @@ class FeatureAttributesBase(dict):
                     errors.extend(self._validate_dtype(data, feature, schema_dtype,
                                                        coerced_df, coerce=coerce))
                 # Check type (float)
-                elif attributes.get('decimal_places', 0) > 0 or self._allows_null(attributes):
+                elif attributes.get('decimal_places', 0) > 0:
                     errors.extend(self._validate_dtype(data, feature, 'float64',
                                                        coerced_df, coerce=coerce))
+                # Check type (nullable Int)
+                elif self._allows_null(attributes):
+                    errors.extend(self._validate_dtype(data, feature, nullable_int_dtype,
+                                                       coerced_df, coerce=coerce))
                 # Check type (int)
                 else:
                     errors.extend(self._validate_dtype(data, feature, 'int64',
                                                        coerced_df, coerce=coerce))
 
             # Check continuous types
-            elif attributes['type'] == 'continuous':
+            else:
                 if 'date_time_format' in attributes:
                     # Check type (datetime)
                     errors.extend(self._validate_dtype(data, feature, 'datetime64',
                                                        coerced_df, coerce=coerce,
                                                        localize_datetimes=localize_datetimes))
-                elif attributes.get('decimal_places', -1) > 0 or self._allows_null(attributes):
-                    # Check type (float)
+                # Check type (float)
+                elif attributes.get('decimal_places', -1) > 0:
                     errors.extend(self._validate_dtype(data, feature, 'float64',
                                                        coerced_df, coerce=coerce))
+                # Check type (nullable Int)
+                elif self._allows_null(attributes):
+                    errors.extend(self._validate_dtype(data, feature, nullable_int_dtype,
+                                                       coerced_df, coerce=coerce))
+                # Check type (int)
                 elif attributes.get('decimal_places', -1) == 0:
-                    # Check type (int)
                     errors.extend(self._validate_dtype(data, feature, 'int64',
                                                        coerced_df, coerce=coerce))
                 elif attributes.get('data_type') == 'number':
@@ -443,7 +476,7 @@ class FeatureAttributesBase(dict):
                                                 coerced_df, coerce=True)):
                         errors.extend([f"Feature '{feature}' should be numeric"
                                        " when 'type' is 'continuous' and "
-                                       "'data_type' is undefined."])
+                                       "'data_type' is 'number'."])
 
             # Check feature bounds
             if validate_bounds:
@@ -574,20 +607,25 @@ class SingleTableFeatureAttributes(FeatureAttributesBase):
 
         Check that feature bounds and data types loosely describe the data. Optionally
         attempt to coerce the data into conformity.
+
         Parameters
         ----------
         data : Any
             The data to validate (single table only).
-        coerce : bool (default False)
+        coerce : bool, default False
             Whether to attempt to coerce DataFrame columns into correct data types.
-        raise_errors : bool (default False)
+        raise_errors : bool, default False
             If True, raises a ValueError if nonconforming columns are found; else, issue a warning.
-        validate_bounds : bool (default True)
+        validate_bounds : bool, default True
             Whether to validate the data against the attributes' inferred bounds.
-        allow_missing_features : bool (default False)
+        allow_missing_features : bool, default False
             Allows features that are missing from the DataFrame to be ignored.
-        localize_datetimes : bool (default True)
+        localize_datetimes : bool, default True
             Whether to localize datetime features to UTC.
+        nullable_int_dtype : str or dtype or ExtensionDtype, default 'Int64'
+            A NumPy Dtype, Pandas Dtype extension object, or string representation thereof to
+            attempt to use when a feature is detected to be an integer and `allow_null=True`
+            in its feature attributes.
 
         Returns
         -------
@@ -597,12 +635,14 @@ class SingleTableFeatureAttributes(FeatureAttributesBase):
         raise NotImplementedError("'data' is an unsupported type")
 
     @validate.register
-    def _(self, data: pd.DataFrame, coerce: bool = False, raise_errors: bool = False, validate_bounds: bool = True,
-          allow_missing_features=False, localize_datetimes=True):
+    def _(self, data: pd.DataFrame, coerce=False, raise_errors=False, validate_bounds=True,
+          allow_missing_features=False, localize_datetimes=True,
+          nullable_int_dtype: str | np.dtype | pd.api.extensions.ExtensionDtype = 'Int64'):
         return self._validate_df(data, coerce=coerce, raise_errors=raise_errors,
                                  validate_bounds=validate_bounds,
                                  allow_missing_features=allow_missing_features,
-                                 localize_datetimes=localize_datetimes)
+                                 localize_datetimes=localize_datetimes,
+                                 nullable_int_dtype=nullable_int_dtype)
 
     def has_unsupported_data(self, feature_name: str) -> bool:
         """
@@ -709,6 +749,7 @@ class InferFeatureAttributesBase(ABC):
                  include_sample: bool = False,
                  infer_bounds: bool = True,
                  max_workers: t.Optional[int] = None,
+                 memory_warning_threshold: t.Optional[int] = 512,
                  mode_bound_features: t.Optional[Iterable[str]] = None,
                  nominal_substitution_config: t.Optional[dict[str, dict]] = None,
                  ordinal_feature_values: t.Optional[dict[str, list[str]]] = None,
@@ -960,11 +1001,24 @@ class InferFeatureAttributesBase(ABC):
                     features.get(feature_name, {}).get('data_type') in ["json", "yaml"]
                 ):
                     continue
-                bounds = self._infer_feature_bounds(
-                    self.attributes, feature_name,
-                    tight_bounds=tight_bounds,
-                    mode_bound_features=mode_bound_features,
-                )
+                try:
+                    bounds = self._infer_feature_bounds(
+                        self.attributes, feature_name,
+                        tight_bounds=tight_bounds,
+                        mode_bound_features=mode_bound_features,
+                    )
+                except ValueError as err:
+                    if "could not convert" in str(err):
+                        # Try to catch any errors on data conversion and suggest something relevant.
+                        if feature_name in preset_types.keys():
+                            suggestion = (f"Please verify that the provided type for '{feature_name}' "
+                                          f"({preset_types[feature_name]['type']}) is reflected by the data.")
+                        else:
+                            suggestion = f"Please verify that cases in '{feature_name}' are of a consistent data type."
+                        raise ValueError(f"The following error was raised while trying to compute bounds for feature "
+                                         f"'{feature_name}':\n\n {err}\n\n{suggestion}")
+                    else:
+                        raise
                 if bounds:
                     # Use `update` on the bounds dictionary in case `allowed` ordinal values have already been set
                     bounds.update(self.attributes[feature_name].get("bounds", {}))
@@ -973,6 +1027,10 @@ class InferFeatureAttributesBase(ABC):
         # Do any features contain data unsupported by the core?
         self._check_unsupported_data(self.attributes)
 
+        # Check if there are any features that consume an unusually large amount of memory
+        if isinstance(self.data, pd.DataFrame):
+            self._check_feature_memory_use(max_size=memory_warning_threshold)
+
         # If requested, infer extended nominals.
         if attempt_infer_extended_nominals:
             # Attempt to import the NominalDetectionEngine.
